<!DOCTYPE html>
<html lang="en">
	<head>
		<title>three.js webgl - particles</title>
		<meta charset="utf-8">
		<meta name="viewport" content="width=device-width, user-scalable=no, minimum-scale=1.0, maximum-scale=1.0">
		<style>
			body {
				background-color:#202020;
				margin: 0px;
				overflow: hidden;
				font-family:Monospace;
				font-size:13px;
				text-align:center;
				font-weight: bold;
				text-align:center;
			}
			a {
				color:#0078ff;
			}
			#under, #over{ position:absolute; pointer-events: none; }
			#under{ z-index:1; }
			#over{ z-index:3; }
			.content{ background-color:#d8d8d8; padding:10vh 15vw; position: absolute; top:40vh; left:35vw; z-index: 2; }
			body .dg.ac{ z-index:5; }
		</style>
	</head>
	<body>
		
		<div id="under"></div>
		<div class="content"></div>
		<div id="over"></div>
		
		<script src="build/three.js"></script>

		<script src="js/Detector.js"></script>
		<script src="js/libs/stats.min.js"></script>
		<script src="js/libs/dat.gui.min.js"></script>

		<script>
			if ( ! Detector.webgl ) Detector.addGetWebGLMessage();
			var container, stats;
			var camera, scene, renderer, particles, geometry, materials = [], parameters, i, h, color, size;
			var mouseX = 0, mouseY = 0;
			var windowHalfX = window.innerWidth / 2;
			var windowHalfY = window.innerHeight / 2;
			
			var effectController = {
				divDepth : 300
			}
			
			init();
			animate();
			
			function init() {
				
				// dat.GUI
				var gui = new dat.GUI( { width: 300 } );
				gui.add(effectController, 'divDepth', 1, 2000);
				
				container = document.getElementById("under");
				containerOver = document.getElementById("over");
				//document.body.appendChild( container );
				camera = new THREE.PerspectiveCamera( 75, window.innerWidth / window.innerHeight, effectController.divDepth, 2000 );
				cameraOver = new THREE.PerspectiveCamera( 75, window.innerWidth / window.innerHeight, 1, effectController.divDepth );
				camera.position.z = 1000;
				cameraOver.position.z = 1000;
				
				scene = new THREE.Scene();
				//scene.fog = new THREE.FogExp2( 0x000000, 0.0007 );
				geometry = new THREE.Geometry();
				for ( i = 0; i < 6000; i ++ ) {
					var vertex = new THREE.Vector3();
					vertex.x = Math.random() * 2000 - 1000;
					vertex.y = Math.random() * 2000 - 1000;
					vertex.z = Math.random() * 2000 - 1000;
					geometry.vertices.push( vertex );
				}
				parameters = [
					[ [1, 1, 0.5], 5 ],
					[ [0.95, 1, 0.5], 4 ],
					[ [0.90, 1, 0.5], 3 ],
					[ [0.85, 1, 0.5], 2 ],
					[ [0.80, 1, 0.5], 1 ]
				];
				for ( i = 0; i < parameters.length; i ++ ) {
					color = parameters[i][0];
					size  = parameters[i][1];
					materials[i] = new THREE.PointsMaterial( { size: size } );
					particles = new THREE.Points( geometry, materials[i] );
					particles.rotation.x = Math.random() * 6;
					particles.rotation.y = Math.random() * 6;
					particles.rotation.z = Math.random() * 6;
					scene.add( particles );
				}
				renderer = new THREE.WebGLRenderer( { alpha: true } );
				renderer.setPixelRatio( window.devicePixelRatio );
				renderer.setSize( window.innerWidth, window.innerHeight );
				
				rendererOver = new THREE.WebGLRenderer( { alpha: true } );
				rendererOver.setPixelRatio( window.devicePixelRatio );
				rendererOver.setSize( window.innerWidth, window.innerHeight );
				
				
				container.appendChild( renderer.domElement );
				containerOver.appendChild( rendererOver.domElement );
				
				stats = new Stats();
				containerOver.appendChild( stats.dom ); //edited
				document.addEventListener( 'mousemove', onDocumentMouseMove, false );
				document.addEventListener( 'touchstart', onDocumentTouchStart, false );
				document.addEventListener( 'touchmove', onDocumentTouchMove, false );
				//
				window.addEventListener( 'resize', onWindowResize, false );
				
				
				
			}
			function onWindowResize() {
				windowHalfX = window.innerWidth / 2;
				windowHalfY = window.innerHeight / 2;
				camera.aspect = window.innerWidth / window.innerHeight;
				camera.updateProjectionMatrix();
				cameraOver.aspect = window.innerWidth / window.innerHeight;
				cameraOver.updateProjectionMatrix();
				renderer.setSize( window.innerWidth, window.innerHeight );
				rendererOver.setSize( window.innerWidth, window.innerHeight );
			}
			function onDocumentMouseMove( event ) {
				mouseX = event.clientX - windowHalfX;
				mouseY = event.clientY - windowHalfY;
			}
			function onDocumentTouchStart( event ) {
				if ( event.touches.length === 1 ) {
					event.preventDefault();
					mouseX = event.touches[ 0 ].pageX - windowHalfX;
					mouseY = event.touches[ 0 ].pageY - windowHalfY;
				}
			}
			function onDocumentTouchMove( event ) {
				if ( event.touches.length === 1 ) {
					event.preventDefault();
					mouseX = event.touches[ 0 ].pageX - windowHalfX;
					mouseY = event.touches[ 0 ].pageY - windowHalfY;
				}
			}
			//
			function animate() {
				requestAnimationFrame( animate );
				render();
				stats.update();
			}
			function render() {
				var time = Date.now() * 0.00005;
				camera.position.x += ( mouseX - camera.position.x ) * 0.01;
				camera.position.y += ( -mouseY - camera.position.y ) * 0.01;
				camera.lookAt( scene.position );
				
				cameraOver.position.x += ( mouseX - camera.position.x ) * 0.01;
				cameraOver.position.y += ( -mouseY - camera.position.y ) * 0.01;
				cameraOver.lookAt( scene.position );
				
				camera.near = effectController.divDepth;
				cameraOver.far = effectController.divDepth;
				
				camera.updateProjectionMatrix();
				cameraOver.updateProjectionMatrix();
				
				//console.log(effectController.divDepth);
				for ( i = 0; i < scene.children.length; i ++ ) {
					var object = scene.children[ i ];
					if ( object instanceof THREE.Points ) {
						object.rotation.y = time * ( i < 4 ? i + 1 : - ( i + 1 ) );
					}
				}
				for ( i = 0; i < materials.length; i ++ ) {
					color = parameters[i][0];
					h = ( 360 * ( color[0] + time ) % 360 ) / 360;
					materials[i].color.setHSL( h, color[1], color[2] );
				}
				renderer.render( scene, camera );
				rendererOver.render( scene, cameraOver );
			}
		</script>
	</body>
</html>